==> bfilter-0.10.1.tar.gz: bfilter-0.10.1/main/gui/win32/AutoIndentingTextCtrl.h <==
/*
    BFilter - a smart ad-filtering web proxy
    Copyright (C) 2002-2005  Joseph Artsimovich <joseph_a@mail.ru>

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/

#ifndef AUTOINDENTINGTEXTCTRL_H_
#define AUTOINDENTINGTEXTCTRL_H_

#ifdef HAVE_CONFIG_H
#include <config.h>
#endif

#include <ace/config.h>
#include <wx/textctrl.h>

class wxCommandEvent;

class AutoIndentingTextCtrl : public wxTextCtrl
{
public:
	AutoIndentingTextCtrl(
		wxWindow* parent, wxWindowID id,
		wxString const& value = wxEmptyString,
		wxPoint const& pos = wxDefaultPosition,
		wxSize const& size = wxDefaultSize,
		long style = wxTE_MULTILINE|wxTE_PROCESS_TAB,
		wxValidator const& validator = wxDefaultValidator,
		wxString const& name = wxTextCtrlNameStr);
	
	virtual ~AutoIndentingTextCtrl();
private:
	void onEnter(wxCommandEvent& evt);
	
	DECLARE_EVENT_TABLE()
};

#endif

==> bfilter_1.0.6.orig.tar.gz: bfilter-1.0.6/main/gui/win32/AutoIndentingTextCtrl.h <==
/*
    BFilter - a smart ad-filtering web proxy
    Copyright (C) 2002-2006  Joseph Artsimovich <joseph_a@mail.ru>

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/

#ifndef AUTOINDENTINGTEXTCTRL_H_
#define AUTOINDENTINGTEXTCTRL_H_

#ifdef HAVE_CONFIG_H
#include <config.h>
#endif

#include <ace/config-lite.h>
#include <wx/textctrl.h>

class wxCommandEvent;

class AutoIndentingTextCtrl : public wxTextCtrl
{
public:
	AutoIndentingTextCtrl(
		wxWindow* parent, wxWindowID id,
		wxString const& value = wxEmptyString,
		wxPoint const& pos = wxDefaultPosition,
		wxSize const& size = wxDefaultSize,
		long style = wxTE_MULTILINE|wxTE_PROCESS_TAB,
		wxValidator const& validator = wxDefaultValidator,
		wxString const& name = wxTextCtrlNameStr);
	
	virtual ~AutoIndentingTextCtrl();
private:
	void onEnter(wxCommandEvent& evt);
	
	DECLARE_EVENT_TABLE()
};

#endif
